@@ -37,7 +37,7 @@ ISOEvaluationMethodType <- R6Class("ISOEvaluationMethodType",
   public = list(
     initialize = function(xml = NULL, value, description = NULL){
       super$initialize(xml = xml, id = private$xmlElement, value = value,
-                       description = description, setValue = FALSE)
+                       description = description)
     }
   )                        
 )
