@@ -37,7 +37,7 @@ ISORoleType <- R6Class("ISORoleType",
    public = list(
      initialize = function(xml = NULL, value, description = NULL){
        super$initialize(xml = xml, id = private$xmlElement, value = value, description = description,
-                        setValue = FALSE, addCodeSpaceAttr = FALSE)
+                        addCodeSpaceAttr = FALSE)
      }
    )                        
 )
