@@ -11,6 +11,9 @@ context("GMLProjectedCRS")
 
 test_that("encoding",{
   
+  testthat::skip_on_cran()
+  testthat::skip_on_travis()
+  
   #encoding
   gml <- GMLProjectedCRS$new(id = "ID")
   gml$setDescriptionReference("someref")
