@@ -9,7 +9,8 @@ require(testthat)
 context("ISOAddress")
 
 test_that("encoding",{
-  
+  testthat::skip_on_cran()
+  testthat::skip_on_travis()
   #encoding
   md <- ISOAddress$new()
   md$setDeliveryPoint("theaddress")
