@@ -9,7 +9,8 @@ require(testthat)
 context("ISOBaseDateTime")
 
 test_that("encoding",{
-  
+  testthat::skip_on_cran()
+  testthat::skip_on_travis()
   #encoding
   md <- ISOBaseDateTime$new(value = ISOdate(2015, 1, 1, 1))
   expect_is(md, "ISOBaseDateTime")
