@@ -9,7 +9,8 @@ require(testthat)
 context("ISOBrowseGraphic")
 
 test_that("encoding",{
-  
+  testthat::skip_on_cran()
+  testthat::skip_on_travis()
   #encoding
   md <- ISOBrowseGraphic$new(
     fileName = "http://wwww.somefile.org/png",
