@@ -9,7 +9,8 @@ require(testthat)
 context("ISOCitation")
 
 test_that("encoding",{
-  
+  testthat::skip_on_cran()
+  testthat::skip_on_travis()
   #encoding
   md <- ISOCitation$new()
   md$setTitle("sometitle")
