@@ -9,7 +9,8 @@ require(testthat)
 context("ISOConformanceResult")
 
 test_that("encoding",{
-  
+  testthat::skip_on_cran()
+  testthat::skip_on_travis()
   #encoding
   md <- ISOConformanceResult$new()
   spec <- ISOCitation$new()
