@@ -9,7 +9,8 @@ require(testthat)
 context("ISOConstraint")
 
 test_that("encoding",{
-  
+  testthat::skip_on_cran()
+  testthat::skip_on_travis()
   md <- ISOConstraint$new(description = "description1")
   expect_equal(md$description, "description1")
   md$setDescription("description2")
