@@ -9,7 +9,8 @@ require(testthat)
 context("ISOConstraints")
 
 test_that("encoding",{
-  
+  testthat::skip_on_cran()
+  testthat::skip_on_travis()
   #encoding
   md <- ISOConstraints$new()
   md$addUseLimitation("limitation1")
