@@ -9,7 +9,8 @@ require(testthat)
 context("ISOContact")
 
 test_that("encoding",{
-  
+  testthat::skip_on_cran()
+  testthat::skip_on_travis()
   #encoding
   md <- ISOContact$new()
   phone <- ISOTelephone$new()
