@@ -9,7 +9,8 @@ require(testthat)
 context("ISOCoupledResource")
 
 test_that("encoding",{
-  
+  testthat::skip_on_cran()
+  testthat::skip_on_travis()
   #encoding
   md <- ISOCoupledResource$new()
   md$setOperationName("operation name")
