@@ -9,7 +9,8 @@ require(testthat)
 context("ISODataIdentification")
 
 test_that("encoding",{
-  
+  testthat::skip_on_cran()
+  testthat::skip_on_travis()
   #encoding
   md <- ISODataIdentification$new()
   md$setAbstract("abstract")
