@@ -9,7 +9,8 @@ require(testthat)
 context("ISODataQualityAbstractElement")
 
 test_that("encoding",{
-  
+  testthat::skip_on_cran()
+  testthat::skip_on_travis()
   #encoding
   dq <- ISODataQualityAbstractElement$new()
   dq$addNameOfMeasure("measure")
