@@ -9,7 +9,8 @@ require(testthat)
 context("ISODefinitionSource")
 
 test_that("encoding",{
-  
+  testthat::skip_on_cran()
+  testthat::skip_on_travis()
   #encoding
   md <- ISODefinitionSource$new()
   citation <- ISOCitation$new()
