@@ -9,7 +9,8 @@ require(testthat)
 context("ISODistribution")
 
 test_that("encoding",{
-  
+  testthat::skip_on_cran()
+  testthat::skip_on_travis()
   #encoding
   md <- ISODistribution$new()
   dto <- ISODigitalTransferOptions$new()  
