@@ -9,7 +9,8 @@ require(testthat)
 context("ISODistributor")
 
 test_that("encoding",{
-  
+  testthat::skip_on_cran()
+  testthat::skip_on_travis()
   #encoding
   md <- ISODistributor$new()
   rp <- ISOResponsibleParty$new()
