@@ -9,7 +9,8 @@ require(testthat)
 context("ISODomainConsistency")
 
 test_that("encoding",{
-  
+  testthat::skip_on_cran()
+  testthat::skip_on_travis()
   #encoding
   md <- ISODomainConsistency$new()
   result <- ISOConformanceResult$new()
