@@ -9,7 +9,8 @@ require(testthat)
 context("ISOFormat")
 
 test_that("encoding",{
-  
+  testthat::skip_on_cran()
+  testthat::skip_on_travis()
   #encoding
   md <- ISOFormat$new()
   md$setName("name")
