@@ -9,7 +9,8 @@ require(testthat)
 context("ISOGridSpatialRepresentation")
 
 test_that("encoding",{
-  
+  testthat::skip_on_cran()
+  testthat::skip_on_travis()
   #encoding
   md <- ISOGridSpatialRepresentation$new()
   md$setNumberOfDimensions(1)
