@@ -9,7 +9,8 @@ require(testthat)
 context("ISOInheritanceRelation")
 
 test_that("encoding",{
-  
+  testthat::skip_on_cran()
+  testthat::skip_on_travis()
   #featuretype
   md <- ISOInheritanceRelation$new()
   md$setName("name")
