@@ -9,7 +9,8 @@ require(testthat)
 context("ISOLegalConstraints")
 
 test_that("encoding",{
-  
+  testthat::skip_on_cran()
+  testthat::skip_on_travis()
   #encoding
   md <- ISOLegalConstraints$new()
   md$addUseLimitation("limitation1")
