@@ -9,7 +9,8 @@ require(testthat)
 context("ISOMaintenanceInformation")
 
 test_that("encoding",{
-  
+  testthat::skip_on_cran()
+  testthat::skip_on_travis()
   #encoding
   md <- ISOMaintenanceInformation$new()
   md$setMaintenanceFrequency("daily")
