@@ -9,7 +9,8 @@ require(testthat)
 context("ISOMemberName")
 
 test_that("encoding",{
-  
+  testthat::skip_on_cran()
+  testthat::skip_on_travis()
   #encoding
   md <- ISOMemberName$new(aName = "name", attributeType = "type")
   expect_is(md, "ISOMemberName")
