@@ -9,7 +9,8 @@ require(testthat)
 context("ISOOnlineResource")
 
 test_that("encoding",{
-  
+  testthat::skip_on_cran()
+  testthat::skip_on_travis()
   #encoding
   md <- ISOOnlineResource$new()
   md$setLinkage("http://somelink")
