@@ -9,7 +9,8 @@ require(testthat)
 context("ISOOperationMetadata")
 
 test_that("encoding",{
-  
+  testthat::skip_on_cran()
+  testthat::skip_on_travis()
   #encoding
   md <- ISOOperationMetadata$new()
   md$setOperationName("Execute")
