@@ -9,7 +9,8 @@ require(testthat)
 context("ISOParameter")
 
 test_that("encoding",{
-  
+  testthat::skip_on_cran()
+  testthat::skip_on_travis()
   #encoding
   md <- ISOParameter$new()
   attrType <- ISOTypeName$new()
