@@ -9,7 +9,8 @@ require(testthat)
 context("ISOPropertyType")
 
 test_that("encoding",{
-  
+  testthat::skip_on_cran()
+  testthat::skip_on_travis()
   #encoding
   md <- ISOPropertyType$new()
   md$setMemberName("name")
