@@ -9,7 +9,8 @@ require(testthat)
 context("ISOResponsibleParty")
 
 test_that("encoding",{
-  
+  testthat::skip_on_cran()
+  testthat::skip_on_travis()
   #encoding
   md <- ISOResponsibleParty$new()
   md$setIndividualName("someone")
