@@ -9,7 +9,8 @@ require(testthat)
 context("ISOSecurityConstraints")
 
 test_that("encoding",{
-  
+  testthat::skip_on_cran()
+  testthat::skip_on_travis()
   #encoding
   md <- ISOSecurityConstraints$new()
   md$setClassification("secret")
