@@ -9,7 +9,8 @@ require(testthat)
 context("ISOStandardOrderProcess")
 
 test_that("encoding",{
-  
+  testthat::skip_on_cran()
+  testthat::skip_on_travis()
   #encoding
   md <- ISOStandardOrderProcess$new()
   md$setFees("fees")
