@@ -9,7 +9,8 @@ require(testthat)
 context("ISOTelephone")
 
 test_that("encoding",{
-  
+  testthat::skip_on_cran()
+  testthat::skip_on_travis()
   #encoding
   md <- ISOTelephone$new()
   md$setVoice("myphonenumber")
