@@ -9,7 +9,8 @@ require(testthat)
 context("ISOTypeName")
 
 test_that("encoding",{
-  
+  testthat::skip_on_cran()
+  testthat::skip_on_travis()
   #encoding
   md <- ISOTypeName$new()
   md$setName("name")
